django-videofield
=================

Support for video upload in Django models.

Instalation
-----------

.. code:: shell

    $ pip install django-videofield

Usage
-----

.. code:: python

    from videofield.models import VideoField

or

.. code:: python

    from videofield.models import VideoField

License
-------

MIT
